//*----------------------------------------------------------------------------
//*         ATMEL Microcontroller Software Support  -  ROUSSET  -
//*----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*----------------------------------------------------------------------------
//* File Name           : main.c
//* Object              : main application written in C
//* Creation            : Hi   11/18/2002
//*
//*----------------------------------------------------------------------------
#include "AT91RM9200.h"
#ifdef __GNUC__
#include "proto.h"			
#else 
#include "lib_AT91RM9200.h"
#endif							/* __GNUC__ */
#include "emac.h"


//* Interrupt Handlers
extern void AT91F_ST_ASM_HANDLER(void);
//* function in init.c
extern void AT91F_DBGU_Printk(char *buffer);
extern void AT91F_DBGU_Printx(unsigned long val);
extern void AT91F_DBGU_Printl(unsigned long val);
extern void AT91F_DBGU_Printv(char * pref, unsigned long val, char *suf);
extern void AT91F_DBGU_Printw(char * pref, unsigned long val, char *suf);
extern int AT91F_DBGU_getch(char * ch);

//* functions in Emac.c
extern int AT91F_EmacEntry(void);
extern int AT91F_ProcessEmacPacket(AT91PS_IPheader pHeader);

//* system timer counter
unsigned int StTick = 0;

unsigned long master_clock = 0;
unsigned long sdram_size = 0;


//*----------------------------------------------------------------------------
//* \fn    AT91F_GetTickCount
//* \brief This function returns the value of the system timer
//* This function is for demonstration purpose only
//*----------------------------------------------------------------------------
unsigned int AT91F_GetTickCount(void)
{
	return(StTick);
}


//*----------------------------------------------------------------------------
//* \fn    AT91F_ST_HANDLER
//* \brief This function is invoked by main
//* This function is for demonstration purpose only
//*----------------------------------------------------------------------------
void AT91F_ST_HANDLER(void)
{
volatile int StStatus;
	// Read the system timer status register
	StStatus = *(AT91C_ST_SR);
	StTick++;
//	AT91F_DBGU_Printk("S");
}


//*----------------------------------------------------------------------------
//* \fn    AT91F_DisplayIpPacket
//* \brief This function is invoked by main
//* This function is for demonstration purpose only
//*----------------------------------------------------------------------------
void AT91F_DisplayIpPacket(AT91PS_IPheader pIpHeader)
{
	AT91F_DBGU_Printk("\n\n\r-I- ================ IP HEADER ======================\n\r");
	AT91F_DBGU_Printv("IP Version        = v.",((pIpHeader->ip_hl_v & 0xF0) >> 4), "\n\r");
	AT91F_DBGU_Printv("Header Length     =   ",pIpHeader->ip_hl_v & 0x0F, "\n\r");
	AT91F_DBGU_Printw("Type of service   = 0x",pIpHeader->ip_tos,"");
	AT91F_DBGU_Printv("Total IP Length   =   ",(pIpHeader->ip_len) >> 8, "\n\r");
	AT91F_DBGU_Printw(" ID                = 0x",(pIpHeader->ip_id), "");
	AT91F_DBGU_Printw("Header Checksum   = 0x",(pIpHeader->ip_sum),"");

	switch(pIpHeader->ip_p) {
		case PROT_IP:
			AT91F_DBGU_Printk("Protocol          = IP\n\r");
		break;
	
		case PROT_ICMP:
			AT91F_DBGU_Printk("Protocol          = ICMP\n\r");
		break;
		default:
			AT91F_DBGU_Printw("Protocol          = 0x",pIpHeader->ip_p,"");
		break;
	}


	AT91F_DBGU_Printk("IP Src Address    = "); 
	AT91F_DBGU_Printl(pIpHeader->ip_src[0]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_src[1]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_src[2]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_src[3]);
	AT91F_DBGU_Printk("\n\r"); 


	AT91F_DBGU_Printk("IP Dest Address   = ");
	AT91F_DBGU_Printl(pIpHeader->ip_dst[0]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_dst[1]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_dst[2]);
	AT91F_DBGU_Printk(":");
	AT91F_DBGU_Printl(pIpHeader->ip_dst[3]);
	AT91F_DBGU_Printk("\n\r");
}



//*----------------------------------------------------------------------------
//* \fn    main
//* \brief 
//* 
//*----------------------------------------------------------------------------
int main()
{
	AT91S_IPheader IpHeader;
	int status;

	AT91F_DBGU_Printk("\n\n\r-I- ======================================\n\r");
	AT91F_DBGU_Printk("-I- AT91RM9200 EMAC Test\n\r");
	AT91F_DBGU_Printk("-I- --------------------------------------\n\r");

	//* System Timer initialization
	AT91F_ST_SetPeriodInterval(AT91C_BASE_ST, AT91C_ST_PITS);
	AT91F_ST_EnableIt(AT91C_BASE_ST, AT91C_ST_PITS);
	AT91F_AIC_ConfigureIt (
							AT91C_BASE_AIC,                        // AIC base address
							AT91C_ID_SYS,                          // System peripheral ID
							AT91C_AIC_PRIOR_HIGHEST,               // Max priority
							AT91C_AIC_SRCTYPE_INT_LEVEL_SENSITIVE,   // Level sensitive
							AT91F_ST_ASM_HANDLER );						
	//* Enable ST interrupt
	AT91F_AIC_EnableIt(AT91C_BASE_AIC, AT91C_ID_SYS);

	//* Initialize AT91RM9200 EMAC
	status = AT91F_EmacEntry();
	if (status)
	{
		AT91F_DBGU_Printw("Error EMAC init: 0x%", status, "");
		while(1);
	}


	while(1) {
		if (AT91F_ProcessEmacPacket(&IpHeader) == AT91C_IPPACKET) {
			AT91F_DisplayIpPacket(&IpHeader);
		}
	}
}